==> flutter_toolkit-0.0.3.tar.gz: lib/path_provider.dart <==
import 'dart:async';
import 'dart:io';

import 'package:flutter/services.dart';

class PathProvider {
  static const MethodChannel _channel =
      const MethodChannel('com.qr.flutter_kit/path_provider');

  static Future<Directory> get getInternalFilesDirectory async {
    String path = await _channel.invokeMethod("getInternalFilesDirectory");
    if (path == null) {
      return null;
    }

    return Directory(path);
  }

  static Future<Directory> get getInternalCacheDirectory async {
    String path = await _channel.invokeMethod("getInternalCacheDirectory");
    if (path == null) {
      return null;
    }

    return Directory(path);
  }

  static Future<Directory> get getExternalFilesDirectory async {
    String path = await _channel.invokeMethod("getExternalFilesDirectory");
    if (path == null) {
      return null;
    }
    return Directory(path);
  }

  static Future<Directory> get getExternalCacheDirectory async {
    String path = await _channel.invokeMethod("getExternalCacheDirectory");
    if (path == null) {
      return null;
    }
    return Directory(path);
  }

  static Future<Directory> get getExternalMusicDirectory async {
    String path =
    await _channel.invokeMethod("getExternalMusicDirectory");
    if (path == null) {
      return null;
    }
    return Directory(path);
  }

  static Future<Directory> get getExternalMoviesDirectory async {
    String path =
    await _channel.invokeMethod("getExternalMoviesDirectory");
    if (path == null) {
      return null;
    }
    return Directory(path);
  }

  static Future<Directory> get getExternalPicturesDirectory async {
    String path =
    await _channel.invokeMethod("getExternalPicturesDirectory");
    if (path == null) {
      return null;
    }
    return Directory(path);
  }

  static Future<Directory> get getExternalDCIMDirectory async {
    String path = await _channel.invokeMethod("getExternalDCIMDirectory");
    if (path == null) {
      return null;
    }
    return Directory(path);
  }

  static Future<Directory> get getExternalDownloadsDirectory async {
    String path =
    await _channel.invokeMethod("getExternalDownloadsDirectory");
    if (path == null) {
      return null;
    }
    return Directory(path);
  }

  static Future<Directory> get getExternalDocumentsDirectory async {
    String path =
    await _channel.invokeMethod("getExternalDocumentsDirectory");
    if (path == null) {
      return null;
    }
    return Directory(path);
  }

  static Future<Directory> get getExternalPublicRootDirectory async {
    String path = await _channel.invokeMethod("getExternalPublicRootDirectory");
    if (path == null) {
      return null;
    }
    return Directory(path);
  }

  static Future<Directory> get getExternalPublicMusicDirectory async {
    String path =
        await _channel.invokeMethod("getExternalPublicMusicDirectory");
    if (path == null) {
      return null;
    }
    return Directory(path);
  }

  static Future<Directory> get getExternalPublicMoviesDirectory async {
    String path =
        await _channel.invokeMethod("getExternalPublicMoviesDirectory");
    if (path == null) {
      return null;
    }
    return Directory(path);
  }

  static Future<Directory> get getExternalPublicPicturesDirectory async {
    String path =
        await _channel.invokeMethod("getExternalPublicPicturesDirectory");
    if (path == null) {
      return null;
    }
    return Directory(path);
  }

  static Future<Directory> get getExternalPublicDCIMDirectory async {
    String path = await _channel.invokeMethod("getExternalPublicDCIMDirectory");
    if (path == null) {
      return null;
    }
    return Directory(path);
  }

  static Future<Directory> get getExternalPublicDownloadsDirectory async {
    String path =
        await _channel.invokeMethod("getExternalPublicDownloadsDirectory");
    if (path == null) {
      return null;
    }
    return Directory(path);
  }

  static Future<Directory> get getExternalPublicDocumentsDirectory async {
    String path =
        await _channel.invokeMethod("getExternalPublicDocumentsDirectory");
    if (path == null) {
      return null;
    }
    return Directory(path);
  }
}

==> flutter_toolkit-0.0.4.tar.gz: lib/path_provider.dart <==
import 'dart:async';
import 'dart:io';

import 'package:flutter/services.dart';

class PathProvider {
  static const MethodChannel _channel =
      const MethodChannel('com.qr.flutter_toolkit/path_provider');

  static Future<Directory> get getInternalFilesDirectory async {
    String path = await _channel.invokeMethod("getInternalFilesDirectory");
    if (path == null) {
      return null;
    }

    return Directory(path);
  }

  static Future<Directory> get getInternalCacheDirectory async {
    String path = await _channel.invokeMethod("getInternalCacheDirectory");
    if (path == null) {
      return null;
    }

    return Directory(path);
  }

  static Future<Directory> get getExternalFilesDirectory async {
    String path = await _channel.invokeMethod("getExternalFilesDirectory");
    if (path == null) {
      return null;
    }
    return Directory(path);
  }

  static Future<Directory> get getExternalCacheDirectory async {
    String path = await _channel.invokeMethod("getExternalCacheDirectory");
    if (path == null) {
      return null;
    }
    return Directory(path);
  }

  static Future<Directory> get getExternalMusicDirectory async {
    String path =
    await _channel.invokeMethod("getExternalMusicDirectory");
    if (path == null) {
      return null;
    }
    return Directory(path);
  }

  static Future<Directory> get getExternalMoviesDirectory async {
    String path =
    await _channel.invokeMethod("getExternalMoviesDirectory");
    if (path == null) {
      return null;
    }
    return Directory(path);
  }

  static Future<Directory> get getExternalPicturesDirectory async {
    String path =
    await _channel.invokeMethod("getExternalPicturesDirectory");
    if (path == null) {
      return null;
    }
    return Directory(path);
  }

  static Future<Directory> get getExternalDCIMDirectory async {
    String path = await _channel.invokeMethod("getExternalDCIMDirectory");
    if (path == null) {
      return null;
    }
    return Directory(path);
  }

  static Future<Directory> get getExternalDownloadsDirectory async {
    String path =
    await _channel.invokeMethod("getExternalDownloadsDirectory");
    if (path == null) {
      return null;
    }
    return Directory(path);
  }

  static Future<Directory> get getExternalDocumentsDirectory async {
    String path =
    await _channel.invokeMethod("getExternalDocumentsDirectory");
    if (path == null) {
      return null;
    }
    return Directory(path);
  }

  static Future<Directory> get getExternalPublicRootDirectory async {
    String path = await _channel.invokeMethod("getExternalPublicRootDirectory");
    if (path == null) {
      return null;
    }
    return Directory(path);
  }

  static Future<Directory> get getExternalPublicMusicDirectory async {
    String path =
        await _channel.invokeMethod("getExternalPublicMusicDirectory");
    if (path == null) {
      return null;
    }
    return Directory(path);
  }

  static Future<Directory> get getExternalPublicMoviesDirectory async {
    String path =
        await _channel.invokeMethod("getExternalPublicMoviesDirectory");
    if (path == null) {
      return null;
    }
    return Directory(path);
  }

  static Future<Directory> get getExternalPublicPicturesDirectory async {
    String path =
        await _channel.invokeMethod("getExternalPublicPicturesDirectory");
    if (path == null) {
      return null;
    }
    return Directory(path);
  }

  static Future<Directory> get getExternalPublicDCIMDirectory async {
    String path = await _channel.invokeMethod("getExternalPublicDCIMDirectory");
    if (path == null) {
      return null;
    }
    return Directory(path);
  }

  static Future<Directory> get getExternalPublicDownloadsDirectory async {
    String path =
        await _channel.invokeMethod("getExternalPublicDownloadsDirectory");
    if (path == null) {
      return null;
    }
    return Directory(path);
  }

  static Future<Directory> get getExternalPublicDocumentsDirectory async {
    String path =
        await _channel.invokeMethod("getExternalPublicDocumentsDirectory");
    if (path == null) {
      return null;
    }
    return Directory(path);
  }
}
